/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.sedona.core.formatMapper;

import org.apache.sedona.common.enums.FileDataSplitter;
import org.apache.sedona.common.enums.GeometryType;

public class PolygonFormatMapper extends FormatMapper {

  /**
   * Instantiates a new polygon format mapper.
   *
   * @param Splitter the splitter
   * @param carryInputData the carry input data
   */
  public PolygonFormatMapper(FileDataSplitter Splitter, boolean carryInputData) {
    super(0, -1, Splitter, carryInputData, GeometryType.POLYGON);
  }

  /**
   * Instantiates a new polygon format mapper.
   *
   * @param startOffset the start offset
   * @param endOffset the end offset
   * @param Splitter the splitter
   * @param carryInputData the carry input data
   */
  public PolygonFormatMapper(
      Integer startOffset, Integer endOffset, FileDataSplitter Splitter, boolean carryInputData) {
    super(startOffset, endOffset, Splitter, carryInputData, GeometryType.POLYGON);
  }
}
